InbrainSurveys class

Constructors

InbrainSurveys()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

areSurveysAvailable() Future<bool>
Check are the surveys available before show the Survey Wall
confirmRewards(List<InBrainReward> rewards) → void
Required for serverless apps.
getCurrencySale() Future<InBrainCurrencySale?>
getNativeSurveys(InBrainFilter filter) Future<List<InBrainSurvey>>
Get native surveys for the user. After survey completed - it becames invalid and cannot be opened again. Please, take care about refreshing surveys with appropriate filter(s). We are proposing to fetch NativeSurveys each time after InBbrainWebView closed and some survey(s) completed. Please, note:
getRewards() Future<List<InBrainReward>>
Required for serverless apps.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWall({InBrainWallOption option = InBrainWallOption.surveys}) Future
Opens the InBrain wall with specified option option Indicates which feature is available at the dashboard: Surveys, Offers, or both (default is all)
setDataOptions(InBrainDataPoints dataOptions) → void
Provide information about the user Contact inBrain to get the additional details
setInbrain({required String apiClientId, required String clientSecret, String? userId}) → void
Initial inBrain SDK configuration
setNavigationBarConfig(InBrainNavbarConfig navigationBarConfig) → void
Customize Navigation Bar to match your application style
setOnSurveysClosedListener(InBrainOnCloseHandler handler) Future<void>
setSessionID(String sessionId) → void
Set the value to track user session. This value is provided via S2S Callbacks as SessionId.
setStatusBarConfig(InBrainStatusBarConfig statusBarConfig) → void
Customize Status Bar to match your application style
setUserID(String userId) → void
Set uniq identifier of user within your application. If value not set (or empty) - deviceId will be used
showNativeSurvey(String searchId, String id, {bool offersEnabled = false}) Future
Show a specific Native Survey. All the configs should be done BEFORE calling showNativeSurvey(). After survey completed - it becames invalid and cannot be opened again. Please, take care about refreshing surveys with appropriate filter(s). We are proposing to fetch NativeSurveys each time after InBbrainWebView closed and some survey(s) completed. Please, note:
showSurveys() Future
Show the Survey Wall. All the configs should be done BEFORE calling openWall() or showNativeSurvey()
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance InbrainSurveys
final